@@ -46,7 +46,7 @@ class Geometry:
             lines[1] = f'geometry_file = \"{path_to_geometry}\"\n'
             lines[-4] = f'proj.SaveAs \"{path_to_cst_file}\", True\n'
 
-        with open('basic_script/script.bas', 'w') as f:
+        with open(path_to_script, 'w') as f:
             f.writelines(lines)
 
         stream = os.popen(f'"{path_to_CST_DE}" -m "{path_to_script}"')
